@@ -31,3 +31,9 @@ class VulnerabilityManagementGateway(metaclass=ABCMeta):
         self, engagement_name, dict_args, secret_tool, config_tool
     ):
         "get_active_engagements"
+
+    @abstractmethod
+    def send_sbom_components(
+        self, sbom_components, service, dict_args, secret_tool, config_tool
+    ):
+        "send_sbom_components"
